import * as React from "react";
import { SpectrumAlertDialogProps, SpectrumDialogProps, SpectrumDialogTriggerProps } from "@react-ui-types/dialog";
import { ModalProps, TrayProps, ConfirmProps } from "@react-ui-types/overlays";
/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
export let AlertDialog: React.ForwardRefExoticComponent<SpectrumAlertDialogProps & React.RefAttributes<import("@react-ui-types/shared").DOMRefValue<HTMLElement>>>;
export interface DialogProps extends SpectrumDialogProps {
    scrolled?: boolean;
    headingClassName?: string;
    headerClassName?: string;
    heroClassName?: string;
    typeIconClassName?: string;
    dividerClassName?: string;
    contentClassName?: string;
    footerClassName?: string;
    buttonGroupClassName?: string;
}
/**
 * Dialogs are windows containing contextual information, tasks, or workflows that appear over the user interface.
 * Depending on the kind of Dialog, further interactions may be blocked until the Dialog is acknowledged.
 */
export let Dialog: React.ForwardRefExoticComponent<DialogProps & React.RefAttributes<import("@react-ui-types/shared").DOMRefValue<HTMLElement>>>;
interface UnderlayProps {
    isOpen?: boolean;
    zIndex?: number;
}
export function Underlay({ isOpen, zIndex }: UnderlayProps): JSX.Element;
export interface WithModalProviderContextType {
    onModalOpenChange: (isOpen: boolean) => void;
    closeAllModals: () => void;
    isModalOpen?: boolean;
}
export interface WithModalProviderProps {
    /** The content of the Provider. */
    children: React.ReactNode;
    className?: string;
    onModalOpenChange?: (isOpen: boolean) => void;
}
export const WithModalProviderContext: React.Context<WithModalProviderContextType>;
export function useProvider(): WithModalProviderContextType;
/**
 * Provider is the container for all React Spectrum applications.
 * It defines the theme, locale, and other application level settings,
 * and can also be used to provide common properties to a group of components.
 */
export let WithModalProvider: React.ForwardRefExoticComponent<WithModalProviderProps & React.RefAttributes<import("@react-ui-types/shared").DOMRefValue<HTMLDivElement>>>;
export let Modal: React.ForwardRefExoticComponent<ModalProps & React.RefAttributes<import("@react-ui-types/shared").DOMRefValue<HTMLDivElement>>>;
export let Tray: React.ForwardRefExoticComponent<TrayProps & React.RefAttributes<import("@react-ui-types/shared").DOMRefValue<HTMLDivElement>>>;
export interface DialogTriggerProps extends SpectrumDialogTriggerProps {
    scrollContent?: boolean;
    closeConfirm?: boolean;
    confirmProps?: ConfirmProps;
}
/**
 * DialogTrigger serves as a wrapper around a Dialog and its associated trigger, linking the Dialog's
 * open state with the trigger's press state. Additionally, it allows you to customize the type and
 * positioning of the Dialog.
 */
export let DialogTrigger: (props: DialogTriggerProps) => JSX.Element;

//# sourceMappingURL=types.d.ts.map
