/*
 * Copyright 2020 Ladifire. All rights reserved.
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 * OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

import * as React from 'react';

import stylex from "@ladifire/stylex";

interface UnderlayProps {
  isOpen?: boolean;
  zIndex?: number;
}

export function Underlay({isOpen, zIndex = 1}: UnderlayProps) {
  return (
    <div
      className={stylex.dedupe(
        {
          position: 'fixed',
          top: 0,
          right: 0,
          bottom: 0,
          left: 0,
          zIndex: 1,
          overflow: 'hidden',
          background: 'var(--overlay-alpha-80)',
        },
        isOpen ? {
          opacity: 1,
          visibility: 'visible',
          transitionDelay: '0ms',
          pointerEvents: 'auto',
          transition: 'opacity var(--lf-duration-extra-extra-short-out) var(--lf-animation-enter-exit-out) 0ms',
        } : {
          opacity: 0,
          visibility: 'hidden',
          pointerEvents: 'none',
          transition: 'opacity var(--lf-duration-extra-extra-short-in) var(--lf-animation-enter-exit-in) 0ms',
        },
      )}
      // className={classNames(
      //   gs,
      //   gs.visibility__hidden,
      //   gs.opacity__0,
      //   gs.position__fixed,
      //   gs.top__0,
      //   gs.right__0,
      //   gs.bottom__0,
      //   gs.left__0,
      //   gs.z_index__1,
      //   gs.overflow_x__hidden,
      //   gs.overflow_y__hidden,
      //   gs.background__black_alpha_40,
      //   gs.transition__opacity_enter_exit_in,
      //   gs.pointer_event__none, {
      //     [gs.opacity__09999]: isOpen,
      //     [gs.visibility__visible]: isOpen,
      //     [gs.transition_delay__0]: isOpen,
      //     [gs.pointer_event__auto]: isOpen,
      //     [gs.transition__opacity_enter_exit_out]: isOpen,
      //   }
      // )}
      {...(zIndex && {style: {zIndex}})}
    />
  );
}
